(this.webpackJsonpui_v2=this.webpackJsonpui_v2||[]).push([[21],{1531:function(e,t,i){},1569:function(e,t,i){"use strict";i.r(t);var l=i(0),a=i.n(l),s=i(1524),n=i(1534),d=i(11),r=i(175),o=(i(1531),i(1));function c(e){var t,i,l=a.a.useRef(null),c=[{dataKey:"step",key:"step",title:"Step",width:100},{dataKey:"index",key:"index",title:"Index",width:100},{dataKey:"text",key:"text",title:"Text",width:0,flexGrow:1,cellRenderer:function(e){var t=e.cellData;return Object(o.jsx)("div",{className:"ScrollBar__hidden",style:{overflow:"auto"},children:Object(o.jsx)("pre",{children:t})})}}],u=(null===e||void 0===e?void 0:e.activeTraceContext.includes("="))?null===e||void 0===e?void 0:e.activeTraceContext.split(",").reduce((function(e,t){var i=t.trim().split("=")[0],l=t.trim().replaceAll('"',"").split("=")[1];return e[i]=l,e}),{}):{};return Object(o.jsx)(d.a,{children:Object(o.jsx)("div",{className:"TextsVisualizer",style:{height:"100%",overflow:"auto"},children:u.dtype?((null===e||void 0===e||null===(t=e.data)||void 0===t?void 0:t.processedValues)||[]).reverse().map((function(t,i){return Object(o.jsxs)("div",{children:[Object(o.jsx)("span",{children:t.step}),Object(o.jsx)("div",{style:{height:"320px"},children:"html"!==u.dtype?Object(o.jsx)(n.a,{onInit:(l=t.text,function(e){e.run(),e.load(l,{sourceType:"immediate",fileType:"pdb"})}),options:{settings:{editing:!0,interpolateViews:!0,zSprite:!0}}}):Object(o.jsx)(s.a,{url:"data:text/html,"+encodeURIComponent(t.text),width:"100%",height:"320px",id:(null===e||void 0===e?void 0:e.activeTraceContext)+i,loading:"lazy",className:"",referrerpolicy:"unsafe-url",title:t.step,display:"block",position:"relative",allowFullScreen:!0,styles:{border:"1px solid #FFA630"}})})]},"boxes-"+i);var l})):Object(o.jsx)(r.a,{tableRef:l,tableData:null===e||void 0===e||null===(i=e.data)||void 0===i?void 0:i.processedValues,tableColumns:c,isLoading:null===e||void 0===e?void 0:e.isLoading,searchableKeys:["text"]})})})}c.displayName="TextsVisualizer";var u=a.a.memo(c);t.default=u}}]);
//# sourceMappingURL=TextsVisualizer.js.map?version=346c9239f5b79f31def0